aboutsummaryrefslogtreecommitdiff
path: root/src/reflist.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/reflist.c')
-rw-r--r--src/reflist.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/reflist.c b/src/reflist.c
index 2bb4e5f6..e543c20d 100644
--- a/src/reflist.c
+++ b/src/reflist.c
@@ -85,7 +85,8 @@ RefList *reflist_new()
new = malloc(sizeof(struct _reflist));
/* Create pseudo-root with invalid indices */
new->head = new_node(SERIAL(257, 257, 257));
return new;
@@ -345,7 +346,7 @@ void delete_refl(Reflection *refl)
Reflection *first_refl(RefList *list)
{
- return list->head;
+ return list->head->child[0];
}
@@ -85,7 +85,8 @@ RefList *reflist_new()
new = malloc(sizeof(struct _reflist));
- /* Create pseudo-root with invalid indices */
+ /* Create pseudo-root with invalid indices.
+ * The "real" root will be the left child of this. */
new->head = new_node(SERIAL(257, 257, 257));
return new;